@@ -740,11 +740,11 @@ void Position::set_queenside_castling_right(char color, bool castle) {
 Move Position::get_move_from_san(const std::string& san) const {
     LegalMoveGenerator legal_moves(*this);
 
-    if (san == "o-o" || san == "o-o-o") {
+    if (san == "O-O" || san == "O-O-O") {
         // Castling moves.
         Square target;
         int rank = m_turn == 'w' ? 0 : 7;
-        if (san == "o-o") {
+        if (san == "O-O") {
             target = Square(rank, 6);
         } else {
             target = Square(rank, 2);
@@ -756,7 +756,7 @@ Move Position::get_move_from_san(const std::string& san) const {
         }
     } else {
         boost::smatch matches;
-        if (boost::regex_match(san, matches, boost::regex("^([NBKRQ])?([a-h])?([1-8])?x?([a-h][1-8])(=[NBRQ])?(\\+|#)?$"), boost::match_extra)) {
+        if (boost::regex_match(san, matches, boost::regex("^([NBKRQ])?([a-h])?([1-8])?x?([a-h][1-8])(=[nbrqNBRQ])?(\\+|#)?$"), boost::match_extra)) {
             // Get the piece type.
             std::string matched_piece(matches[1].first, matches[1].second);
             Piece piece = Piece::from_color_and_type(
@@ -775,7 +775,7 @@ Move Position::get_move_from_san(const std::string& san) const {
 
             // Get the promotion type.
             std::string matched_promotion(matches[5].first, matches[5].second);
-            char promotion = matched_promotion == "" ? 0 : tolower(matched_promotion.at(0));
+            char promotion = matched_promotion == "" ? 0 : tolower(matched_promotion.at(1));
 
             // Find a matching move.
             legal_moves.__iter__();
@@ -924,9 +924,9 @@ MoveInfo Position::make_move(const Move& move) {
 
     // Generate the SAN.
     if (info.is_kingside_castle()) {
-        info.set_san("o-o");
+        info.set_san("O-O");
     } else if (info.is_queenside_castle()) {
-        info.set_san("o-o-o");
+        info.set_san("O-O-O");
     } else {
         // Add the piece type.
         if (info.piece().type() != 'p') {
